@@ -18,14 +18,14 @@ import { getImagingProvider } from '../../integrations/imaging';
 
 async function renderResults({ models, settings }, imagingRequest) {
   const results = imagingRequest.results
-    ?.filter((result) => !result.deletedAt)
-    .map((result) => result.get({ plain: true }));
+    ?.filter(result => !result.deletedAt)
+    .map(result => result.get({ plain: true }));
   if (!results || results.length === 0) return results;
 
   const imagingProvider = await getImagingProvider(models, settings);
   if (imagingProvider) {
     const urls = await Promise.all(
-      imagingRequest.results.map(async (result) => {
+      imagingRequest.results.map(async result => {
         // catch all errors so we never fail to show the request if the external provider errors
         try {
           const url = await imagingProvider.getUrlForResult(result);
@@ -39,7 +39,7 @@ async function renderResults({ models, settings }, imagingRequest) {
     );
 
     for (const result of results) {
-      const externalResult = urls.find((url) => url?.resultId === result.id);
+      const externalResult = urls.find(url => url?.resultId === result.id);
       if (!externalResult) continue;
 
       const { url, err } = externalResult;
@@ -137,7 +137,7 @@ imagingRequest.get(
           ],
         },
       ],
-    }); 
+    });
     if (!imagingRequestObject) throw new NotFoundError();
 
     await req.audit.access({
@@ -259,7 +259,7 @@ imagingRequest.post(
   '/$',
   asyncHandler(async (req, res) => {
     const {
-      models: { ImagingRequest },
+      models: { ImagingRequest, ImagingRequestArea },
       user,
       body: { areas, note, areaNote, ...imagingRequestData },
     } = req;
@@ -275,7 +275,12 @@ imagingRequest.post(
 
       // Creates the reference data associations for the areas to be imaged
       if (areas) {
-        await newImagingRequest.setAreas(JSON.parse(areas));
+        for (const area of JSON.parse(areas)) {
+          await ImagingRequestArea.create({
+            areaId: area,
+            imagingRequestId: newImagingRequest.id,
+          });
+        }
       }
 
       if (note) {
@@ -465,7 +470,7 @@ globalImagingRequests.get(
     const { count } = databaseResponse;
     const { rows } = databaseResponse;
 
-    const data = rows.map((row) => row.get({ plain: true }));
+    const data = rows.map(row => row.get({ plain: true }));
     res.send({
       count,
       data,
