@@ -1,13 +1,13 @@
 import express from 'express';
 import asyncHandler from 'express-async-handler';
 import { literal, QueryTypes, Op } from 'sequelize';
-import { snakeCase, keyBy } from 'lodash';
+import { snakeCase } from 'lodash';
 
 import {
   createPatientSchema,
   updatePatientSchema,
 } from '@tamanu/shared/schemas/facility/requests/createPatient.schema';
-import { NotFoundError, InvalidParameterError } from '@tamanu/errors';
+import { NotFoundError, InvalidParameterError, ValidationError } from '@tamanu/errors';
 import {
   PATIENT_REGISTRY_TYPES,
   VISIBILITY_STATUSES,
@@ -15,7 +15,7 @@ import {
   ENCOUNTER_TYPES,
   DRUG_ROUTE_LABELS,
 } from '@tamanu/constants';
-import { isGeneratedDisplayId } from '@tamanu/utils/generateId';
+import { isGeneratedDisplayId, isGeneratedIdFromPattern } from '@tamanu/utils/generateId';
 
 import { renameObjectKeys } from '@tamanu/utils/renameObjectKeys';
 import { createPatientFilters } from '../../../utils/patientFilters';
@@ -32,6 +32,7 @@ import {
 import { dbRecordToResponse, pickPatientBirthData, requestBodyToRecord } from './utils';
 import { PATIENT_SORT_KEYS } from './constants';
 import { getWhereClausesAndReplacementsFromFilters } from '../../../utils/query';
+import { getLastOrderedAtForOngoingPrescriptions } from '../../../utils/medication';
 import { validate } from '../../../utils/validate';
 import { patientContact } from './patientContact';
 import { patientPortal } from './patientPortal';
@@ -94,6 +95,7 @@ patientRoute.put(
     const {
       db,
       models: { Patient, PatientAdditionalData, PatientBirthData, PatientSecondaryId },
+      settings,
       params,
       body: { facilityId, ...body },
     } = req;
@@ -108,12 +110,25 @@ patientRoute.put(
 
     const validatedBody = validate(updatePatientSchema, { ...body, facilityId });
 
+    const patientDisplayIdPattern = await settings[facilityId].get('patientDisplayIdPattern');
+
     await db.transaction(async () => {
       // First check if displayId changed to create a secondaryId record
       if (validatedBody.displayId && validatedBody.displayId !== patient.displayId) {
-        const oldDisplayIdType = isGeneratedDisplayId(patient.displayId)
-          ? 'secondaryIdType-tamanu-display-id'
-          : 'secondaryIdType-nhn';
+        const existingPatients = await Patient.count({
+          where: { displayId: validatedBody.displayId },
+        });
+        if (existingPatients > 0) {
+          throw new ValidationError(
+            `Display ID ${validatedBody.displayId} is already in use by another patient`,
+          );
+        }
+
+        const oldDisplayIdType =
+          isGeneratedDisplayId(patient.displayId) ||
+          isGeneratedIdFromPattern(patient.displayId, patientDisplayIdPattern)
+            ? 'secondaryIdType-tamanu-display-id'
+            : 'secondaryIdType-nhn';
         await PatientSecondaryId.create({
           value: patient.displayId,
           visibilityStatus: VISIBILITY_STATUSES.HISTORICAL,
@@ -590,36 +605,14 @@ patientRoute.get(
     if (responseData.length > 0) {
       const ongoingPrescriptionIds = responseData.map(p => p.id);
 
-      // Find the latest pharmacy_order_prescriptions for prescriptions that were cloned from ongoing prescriptions.
-      const [pharmacyOrderPrescriptions] = await db.query(
-        `
-        SELECT
-          p_ongoing.id as ongoing_prescription_id,
-          MAX(pop.created_at) as last_ordered_at
-        FROM prescriptions p_ongoing
-        INNER JOIN prescriptions p_cloned ON p_cloned.medication_id = p_ongoing.medication_id
-          AND p_cloned.deleted_at IS NULL
-        INNER JOIN encounter_prescriptions ep_cloned ON ep_cloned.prescription_id = p_cloned.id
-        INNER JOIN encounters e ON e.id = ep_cloned.encounter_id
-          AND e.patient_id = :patientId
-          AND e.reason_for_encounter = 'Medication dispensing'
-        INNER JOIN pharmacy_order_prescriptions pop ON pop.prescription_id = p_cloned.id
-          AND pop.deleted_at IS NULL
-        WHERE p_ongoing.id IN (:ongoingPrescriptionIds)
-        GROUP BY p_ongoing.id
-      `,
-        {
-          replacements: {
-            patientId,
-            ongoingPrescriptionIds,
-          },
-        },
+      const lastOrderedAts = await getLastOrderedAtForOngoingPrescriptions(
+        db,
+        ongoingPrescriptionIds,
       );
-      const lastOrderedAts = keyBy(pharmacyOrderPrescriptions, 'ongoing_prescription_id');
 
       responseData = responseData.map(p => ({
         ...p,
-        lastOrderedAt: lastOrderedAts[p.id]?.last_ordered_at?.toISOString(),
+        lastOrderedAt: lastOrderedAts[p.id]?.last_ordered_at,
       }));
     }
 
